#include <stdio.h>
#include <math.h>

#define MAXBC 127

typedef struct
{
  double re;
  double im;
}
Complex;

typedef enum
{
  QUIT=0, ADD=1, SUB=2, MPY=3, DIV=4, MOD=5, ERR=6
}
Operation;

int fread_complex (FILE *fh, Complex *np)
{
  char buf[MAXBC+1];
  Complex n;

  if (fgets (buf, MAXBC, fh) == NULL)
    return 0;
  if (sscanf (buf, "%lf %lf", &np->re, &np->im) != 2)
    return 0;
  return 1;
}

int read_varcomplex (char *varname, Complex *np)
{
  printf ("%s? ", varname);
  return fread_complex (stdin, np);
}

int fwrite_complex (FILE *fh, const Complex n)
{
  if (fprintf (fh, "%lf %+lf i\n", n.re, n.im) == EOF)
    return 0;
  else
    return 1;
}

void write_varcomplex (char *varname, const Complex n)
{
  printf ("%s = ", varname);
  fwrite_complex (stdout, n);
}


Complex add_complex (Complex a, Complex b)
{
  Complex ris;
  ris.re = a.re + b.re;
  ris.im = a.im + b.im;
  return ris;
}


Complex sub_complex (Complex a, Complex b)
{
  Complex ris;
  ris.re = a.re - b.re;
  ris.im = a.im - b.im;
  return ris;
}

double mod_complex (Complex a)
{
  return sqrt (a.re*a.re + a.im*a.im);
}

Complex mpy_complex (Complex a, Complex b)
{
  Complex ris;
  ris.re = a.re * b.re - a.im * b.im;
  ris.im = a.im * b.re + b.im * a.re;
  return ris;
}


Complex div_complex (Complex a, Complex b)
{
  Complex ris;
  double m = mod_complex(b);
  ris.re = (a.re*b.re + a.im*b.im) / (m*m);
  ris.im = (a.im*b.re - a.re*b.im) / (m*m);
  return ris;
}

Operation menu (void)
{
  char buf[MAXBC+1];
  int scelta;

  printf ("\n%s%s%s%s%s%s%s%s",
    "Operazioni su numeri complessi:\n",
    "  0 ... fine programma\n",
    "  1 ... addizione\n",
    "  2 ... sottrazione\n",
    "  3 ... moltiplicazione\n",
    "  4 ... divisione\n",
    "  5 ... modulo\n",
    "Scelta [0-5]? "
    );
  if (fgets (buf,MAXBC,stdin) == NULL)
    return ERR;
  if (sscanf (buf,"%d",&scelta) != 1 || scelta<0 || scelta>5)
    return ERR;
  return (Operation)scelta;
}


int main ()
{
  Complex a, b, ris;

  while (1)
  switch (menu())
  {
  case QUIT:
    return 0;
    break;

  case ADD:
    if (read_varcomplex("ALFA",&a) != 1)
      fprintf (stderr, "errore - input errato\n");
    else if (read_varcomplex("BETA",&b) != 1)
      fprintf (stderr, "errore - input errato\n");
    else
      write_varcomplex ("\nALFA + BETA", add_complex(a,b));
    break;

  case SUB:
    if (read_varcomplex("ALFA",&a) != 1)
      fprintf (stderr, "errore - input errato\n");
    else if (read_varcomplex("BETA",&b) != 1)
      fprintf (stderr, "errore - input errato\n");
    else
      write_varcomplex ("\nALFA - BETA", sub_complex(a,b));
    break;

  case MPY:
    if (read_varcomplex("ALFA",&a) != 1)
      fprintf (stderr, "errore - input errato\n");
    else if (read_varcomplex("BETA",&b) != 1)
      fprintf (stderr, "errore - input errato\n");
    else
      write_varcomplex ("\nALFA * BETA", mpy_complex(a,b));
    break;

  case DIV :
    if (read_varcomplex("ALFA",&a) != 1)
      fprintf (stderr, "errore - input errato\n");
    else if (read_varcomplex("BETA",&b) != 1)
      fprintf (stderr, "errore - input errato\n");
    else
      write_varcomplex ("\nALFA / BETA", div_complex(a,b));
    break;

  case MOD :
    if (read_varcomplex("ALFA",&a) != 1)
      fprintf (stderr, "errore - input errato");
    else
      printf ("\n|ALFA| = %lf\n", mod_complex (a));
    break;

  case ERR:
    fprintf (stderr, "errore - fai una delle scelte proposte\n");
    break;

  default:
    fprintf (stderr, "bug - scelta impossibile");
    return 1;
  }
}
