#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define MAXDIM 100
#define MAXBC 127

double distn (const double a[], const double b[], const int n)
{
  int i;
  double d = 0.0;

  for (i=0; i<n; i++)
    d += (a[i]-b[i]) * (a[i]-b[i]);
  return sqrt(d);
}

int freadv (FILE *fh, double x[], const int maxdim)
{
  int ndim = 0;
  char buf[MAXBC+1];

  while (fgets(buf,MAXBC+1,fh) != NULL)
  {
    double y;
    if (sscanf(buf,"%lf", &y) != 1)
      return 0;
    if (ndim >= maxdim)
      return 0;
    x[ndim] = y;
    ndim++;
  }
  return ndim;
}


int main (int argc, char *argv[])
{
  FILE *af;
  FILE *bf;
  double a[MAXDIM], b[MAXDIM];
  int adim, bdim, ndim;
  double ris;

  /* controllo i parametri */

  if (argc != 3) {
    fprintf (stderr, "errore - fornire i nomi di due file\n");
    exit (1);
  }

  /* leggo il primo punto */

  af = fopen (argv[1],"r");
  if (af == NULL) {
    fprintf (stderr, "errore - non riesco ad aprire il file '%s'\n", argv[1]);
    exit (2);
  }

  adim = freadv (af, a, MAXDIM);
  if (adim == 0) {
    fprintf (stderr, "errore - fallita la lettura del punto dal file '%s'\n", argv[1]);
    exit (3);
  }

  if (fclose(af) != 0)
    fprintf (stderr, "avviso: non riesco a chiudere il file '%s'\n", argv[1]);

  /* leggo il secondo punto */

  bf = fopen (argv[2],"r");
  if (bf == NULL) {
    fprintf (stderr, "errore - non riesco ad aprire il file '%s'\n", argv[2]);
    exit (2);
  }

  bdim = freadv (bf, b, MAXDIM);
  if (bdim == 0) {
    fprintf (stderr, "errore - fallita la lettura del punto dal file '%s'\n", argv[2]);
    exit (3);
  }

  if (fclose(bf) != 0)
    fprintf (stderr, "avviso: non riesco a chiudere il file '%s'\n", argv[2]);

  /* controllo che le dimensioni siano uguali */

  if (adim != bdim) {
    fprintf (stderr,
      "errore - i due punti non hanno la stessa dimensione (%d != %d)\n", adim, bdim);
    exit (4);
  }

  ndim = adim;

  /* calcolo la distanza */

  ris = distn (a, b, ndim);

  /* scrivo il risultato */

  printf ("distanza = %lf\n", ris);

  return 0;
}
